@@ -2,8 +2,9 @@ example.config <- function(result.dir, config)
 {
   message('This is a demo run for GWASinspector package.')
 
-   Sys.sleep(2)
+  Sys.sleep(2)
 
+  .QC$verbose <- TRUE
 
   # remove the trailing backslash from path
   result.dir <- gsub('/+$', '' , result.dir)
@@ -37,6 +38,7 @@ example.config <- function(result.dir, config)
 
   config$output_parameters$object_file <- FALSE
   config$output_parameters$add_column_multiallelic <- FALSE
+  config$output_parameters$add_column_HQ <- FALSE
   config$output_parameters$add_column_AFmismatch <- FALSE
   config$output_parameters$add_column_rsid <- FALSE
   config$output_parameters$add_column_AF <- FALSE
